Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1480)

Unified Diff: storage/browser/fileapi/watcher_manager.h

Issue 689603002: [fsp] Implement storage::WatcherManager for FSP. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed. Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_browser_chromeos.gypi ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: storage/browser/fileapi/watcher_manager.h
diff --git a/storage/browser/fileapi/watcher_manager.h b/storage/browser/fileapi/watcher_manager.h
index 1c4f3d1a76ec7658b937ca21a5bc220b4644f625..e38d207b0f0810690a2e94da7dd568d52f536b0d 100644
--- a/storage/browser/fileapi/watcher_manager.h
+++ b/storage/browser/fileapi/watcher_manager.h
@@ -11,10 +11,6 @@
#include "base/callback_forward.h"
#include "base/files/file.h"
-namespace base {
-class Time;
-}
-
namespace storage {
class FileSystemOperationContext;
@@ -27,28 +23,34 @@ class FileSystemURL;
// can assume that they don't get any null callbacks.
class WatcherManager {
public:
- enum Action { CHANGED, REMOVED };
+ enum ChangeType { CHANGED, DELETED };
typedef base::Callback<void(base::File::Error result)> StatusCallback;
- typedef base::Callback<void(Action action)> NotificationCallback;
+ typedef base::Callback<void(ChangeType change_type)> NotificationCallback;
virtual ~WatcherManager() {}
// Observes a directory entry. If the |recursive| mode is not supported then
// FILE_ERROR_INVALID_OPERATION must be returned as an error. If the |url| is
- // already watched, or setting up the watcher fails, then |callback|
- // must be called with a specific error code. Otherwise |callback| must be
- // called with the FILE_OK error code. |notification_callback| is called for
- // every change related to the watched directory.
- virtual void WatchDirectory(
+ // already watched with the same |recursive|, or setting up the watcher fails,
+ // then |callback| must be called with a specific error code.
+ //
+ // There may be up to two watchers for the same |url| as well as one of them
+ // is recursive, and the other one is not.
+ //
+ // In case of a success |callback| must be called with the FILE_OK error code.
+ // |notification_callback| is called for every change related to the watched
+ // directory.
+ virtual void AddWatcher(
const FileSystemURL& url,
bool recursive,
const StatusCallback& callback,
const NotificationCallback& notification_callback) = 0;
- // Stops observing an entry represented by |url|.
- virtual void UnwatchEntry(const FileSystemURL& url,
- const StatusCallback& callback) = 0;
+ // Removes a watcher represented by |url| in |recursive| mode.
+ virtual void RemoveWatcher(const FileSystemURL& url,
+ bool recursive,
+ const StatusCallback& callback) = 0;
};
} // namespace storage
« no previous file with comments | « chrome/chrome_browser_chromeos.gypi ('k') | no next file » | no next file with comments »
@@ -27,28 +23,34 @@ class FileSystemURL;
virtual ~WatcherManager() {}
- // Observes a directory entry. If the |recursive| mode is not supported then
+ // Adds an entry watcher. If the |recursive| mode is not supported then
// FILE_ERROR_INVALID_OPERATION must be returned as an error. If the |url| is

Powered by Google App Engine
This is Rietveld 408576698